# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import unrealon_pb2 as unrealon__pb2

GRPC_GENERATED_VERSION = '1.76.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + ' but the generated code in unrealon_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class UnrealonServiceStub(object):
    """═══════════════════════════════════════════════════════════
    MAIN SERVICE
    ═══════════════════════════════════════════════════════════

    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Connect = channel.stream_stream(
                '/unrealon.v1.UnrealonService/Connect',
                request_serializer=unrealon__pb2.ClientMessage.SerializeToString,
                response_deserializer=unrealon__pb2.ServerMessage.FromString,
                _registered_method=True)
        self.Register = channel.unary_unary(
                '/unrealon.v1.UnrealonService/Register',
                request_serializer=unrealon__pb2.RegisterRequest.SerializeToString,
                response_deserializer=unrealon__pb2.RegisterResponse.FromString,
                _registered_method=True)
        self.Deregister = channel.unary_unary(
                '/unrealon.v1.UnrealonService/Deregister',
                request_serializer=unrealon__pb2.DeregisterRequest.SerializeToString,
                response_deserializer=unrealon__pb2.DeregisterResponse.FromString,
                _registered_method=True)


class UnrealonServiceServicer(object):
    """═══════════════════════════════════════════════════════════
    MAIN SERVICE
    ═══════════════════════════════════════════════════════════

    """

    def Connect(self, request_iterator, context):
        """Bidirectional stream for all SDK ↔ Server communication
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Register(self, request, context):
        """Unary RPCs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Deregister(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UnrealonServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Connect': grpc.stream_stream_rpc_method_handler(
                    servicer.Connect,
                    request_deserializer=unrealon__pb2.ClientMessage.FromString,
                    response_serializer=unrealon__pb2.ServerMessage.SerializeToString,
            ),
            'Register': grpc.unary_unary_rpc_method_handler(
                    servicer.Register,
                    request_deserializer=unrealon__pb2.RegisterRequest.FromString,
                    response_serializer=unrealon__pb2.RegisterResponse.SerializeToString,
            ),
            'Deregister': grpc.unary_unary_rpc_method_handler(
                    servicer.Deregister,
                    request_deserializer=unrealon__pb2.DeregisterRequest.FromString,
                    response_serializer=unrealon__pb2.DeregisterResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'unrealon.v1.UnrealonService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('unrealon.v1.UnrealonService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class UnrealonService(object):
    """═══════════════════════════════════════════════════════════
    MAIN SERVICE
    ═══════════════════════════════════════════════════════════

    """

    @staticmethod
    def Connect(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(
            request_iterator,
            target,
            '/unrealon.v1.UnrealonService/Connect',
            unrealon__pb2.ClientMessage.SerializeToString,
            unrealon__pb2.ServerMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Register(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/unrealon.v1.UnrealonService/Register',
            unrealon__pb2.RegisterRequest.SerializeToString,
            unrealon__pb2.RegisterResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Deregister(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/unrealon.v1.UnrealonService/Deregister',
            unrealon__pb2.DeregisterRequest.SerializeToString,
            unrealon__pb2.DeregisterResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
