# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: unrealon.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'unrealon.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0eunrealon.proto\x12\x0bunrealon.v1\"\xae\x02\n\rClientMessage\x12\x12\n\nservice_id\x18\x01 \x01(\t\x12\x10\n\x08sequence\x18\x02 \x01(\x03\x12+\n\theartbeat\x18\n \x01(\x0b\x32\x16.unrealon.v1.HeartbeatH\x00\x12%\n\x04logs\x18\x0b \x01(\x0b\x32\x15.unrealon.v1.LogBatchH\x00\x12.\n\x0b\x63ommand_ack\x18\x0c \x01(\x0b\x32\x17.unrealon.v1.CommandAckH\x00\x12\x32\n\rstatus_update\x18\r \x01(\x0b\x32\x19.unrealon.v1.StatusUpdateH\x00\x12\x34\n\x0emetrics_update\x18\x0e \x01(\x0b\x32\x1a.unrealon.v1.MetricsUpdateH\x00\x42\t\n\x07payload\"H\n\tHeartbeat\x12\x0e\n\x06status\x18\x01 \x01(\t\x12+\n\x07metrics\x18\x02 \x01(\x0b\x32\x1a.unrealon.v1.SystemMetrics\"~\n\rSystemMetrics\x12\x11\n\tmemory_mb\x18\x01 \x01(\x02\x12\x13\n\x0b\x63pu_percent\x18\x02 \x01(\x02\x12\x16\n\x0euptime_seconds\x18\x03 \x01(\x02\x12\x17\n\x0fitems_processed\x18\x04 \x01(\x03\x12\x14\n\x0c\x65rrors_count\x18\x05 \x01(\x03\"2\n\x08LogBatch\x12&\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x15.unrealon.v1.LogEntry\"L\n\x08LogEntry\x12\r\n\x05level\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\t\x12\r\n\x05\x65xtra\x18\x04 \x01(\t\"k\n\nCommandAck\x12\x12\n\ncommand_id\x18\x01 \x01(\t\x12*\n\x06status\x18\x02 \x01(\x0e\x32\x1a.unrealon.v1.CommandStatus\x12\x0e\n\x06result\x18\x03 \x01(\t\x12\r\n\x05\x65rror\x18\x04 \x01(\t\"5\n\x0cStatusUpdate\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x15\n\rerror_message\x18\x02 \x01(\t\"J\n\rMetricsUpdate\x12\x1d\n\x15items_processed_delta\x18\x01 \x01(\x03\x12\x1a\n\x12\x65rrors_count_delta\x18\x02 \x01(\x03\"\xf1\x01\n\rServerMessage\x12\x10\n\x08sequence\x18\x01 \x01(\x03\x12\x32\n\rheartbeat_ack\x18\n \x01(\x0b\x32\x19.unrealon.v1.HeartbeatAckH\x00\x12\'\n\x07\x63ommand\x18\x0b \x01(\x0b\x32\x14.unrealon.v1.CommandH\x00\x12\x32\n\rconfig_update\x18\x0c \x01(\x0b\x32\x19.unrealon.v1.ConfigUpdateH\x00\x12\x32\n\rserver_status\x18\r \x01(\x0b\x32\x19.unrealon.v1.ServerStatusH\x00\x42\t\n\x07payload\"O\n\x0cHeartbeatAck\x12\x10\n\x08received\x18\x01 \x01(\x08\x12\x13\n\x0bserver_time\x18\x02 \x01(\t\x12\x18\n\x10\x63ommands_pending\x18\x03 \x01(\x05\"Y\n\x07\x43ommand\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0e\n\x06params\x18\x03 \x01(\t\x12\x12\n\ntimeout_ms\x18\x04 \x01(\x03\x12\x10\n\x08priority\x18\x05 \x01(\x05\"J\n\x0c\x43onfigUpdate\x12\"\n\x1aheartbeat_interval_seconds\x18\x01 \x01(\x05\x12\x16\n\x0elog_batch_size\x18\x02 \x01(\x05\">\n\x0cServerStatus\x12\x1d\n\x15\x61\x63\x63\x65pting_connections\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"\xc9\x01\n\x0fRegisterRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08hostname\x18\x02 \x01(\t\x12\x0b\n\x03pid\x18\x03 \x01(\x05\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x13\n\x0bsource_code\x18\x05 \x01(\t\x12\x17\n\x0f\x65xecutable_path\x18\x06 \x01(\t\x12\x19\n\x11working_directory\x18\x07 \x01(\t\x12\x13\n\x0bsdk_version\x18\x08 \x01(\t\x12\x16\n\x0epython_version\x18\t \x01(\t\"\x90\x01\n\x10RegisterResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x12\n\nservice_id\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x13\n\x0bserver_time\x18\x04 \x01(\t\x12\x31\n\x0einitial_config\x18\x05 \x01(\x0b\x32\x19.unrealon.v1.ConfigUpdate\"7\n\x11\x44\x65registerRequest\x12\x12\n\nservice_id\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\"6\n\x12\x44\x65registerResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t*k\n\rCommandStatus\x12\x1e\n\x1a\x43OMMAND_STATUS_UNSPECIFIED\x10\x00\x12\x10\n\x0c\x41\x43KNOWLEDGED\x10\x01\x12\r\n\tEXECUTING\x10\x02\x12\r\n\tCOMPLETED\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\x32\xf6\x01\n\x0fUnrealonService\x12G\n\x07\x43onnect\x12\x1a.unrealon.v1.ClientMessage\x1a\x1a.unrealon.v1.ServerMessage\"\x00(\x01\x30\x01\x12I\n\x08Register\x12\x1c.unrealon.v1.RegisterRequest\x1a\x1d.unrealon.v1.RegisterResponse\"\x00\x12O\n\nDeregister\x12\x1e.unrealon.v1.DeregisterRequest\x1a\x1f.unrealon.v1.DeregisterResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'unrealon_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_COMMANDSTATUS']._serialized_start=1928
  _globals['_COMMANDSTATUS']._serialized_end=2035
  _globals['_CLIENTMESSAGE']._serialized_start=32
  _globals['_CLIENTMESSAGE']._serialized_end=334
  _globals['_HEARTBEAT']._serialized_start=336
  _globals['_HEARTBEAT']._serialized_end=408
  _globals['_SYSTEMMETRICS']._serialized_start=410
  _globals['_SYSTEMMETRICS']._serialized_end=536
  _globals['_LOGBATCH']._serialized_start=538
  _globals['_LOGBATCH']._serialized_end=588
  _globals['_LOGENTRY']._serialized_start=590
  _globals['_LOGENTRY']._serialized_end=666
  _globals['_COMMANDACK']._serialized_start=668
  _globals['_COMMANDACK']._serialized_end=775
  _globals['_STATUSUPDATE']._serialized_start=777
  _globals['_STATUSUPDATE']._serialized_end=830
  _globals['_METRICSUPDATE']._serialized_start=832
  _globals['_METRICSUPDATE']._serialized_end=906
  _globals['_SERVERMESSAGE']._serialized_start=909
  _globals['_SERVERMESSAGE']._serialized_end=1150
  _globals['_HEARTBEATACK']._serialized_start=1152
  _globals['_HEARTBEATACK']._serialized_end=1231
  _globals['_COMMAND']._serialized_start=1233
  _globals['_COMMAND']._serialized_end=1322
  _globals['_CONFIGUPDATE']._serialized_start=1324
  _globals['_CONFIGUPDATE']._serialized_end=1398
  _globals['_SERVERSTATUS']._serialized_start=1400
  _globals['_SERVERSTATUS']._serialized_end=1462
  _globals['_REGISTERREQUEST']._serialized_start=1465
  _globals['_REGISTERREQUEST']._serialized_end=1666
  _globals['_REGISTERRESPONSE']._serialized_start=1669
  _globals['_REGISTERRESPONSE']._serialized_end=1813
  _globals['_DEREGISTERREQUEST']._serialized_start=1815
  _globals['_DEREGISTERREQUEST']._serialized_end=1870
  _globals['_DEREGISTERRESPONSE']._serialized_start=1872
  _globals['_DEREGISTERRESPONSE']._serialized_end=1926
  _globals['_UNREALONSERVICE']._serialized_start=2038
  _globals['_UNREALONSERVICE']._serialized_end=2284
# @@protoc_insertion_point(module_scope)
